==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerCaptureHTTPCookieFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressControllerCaptureHTTPCookieFluent<A extends io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMatchType();
  public A withMatchType(java.lang.String matchType);
  public java.lang.Boolean hasMatchType();
  
  /**
   * Method is deprecated. use withMatchType instead.
   */
  @java.lang.Deprecated
  public A withNewMatchType(java.lang.String arg0);
  public java.lang.Integer getMaxLength();
  public A withMaxLength(java.lang.Integer maxLength);
  public java.lang.Boolean hasMaxLength();
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getNamePrefix();
  public A withNamePrefix(java.lang.String namePrefix);
  public java.lang.Boolean hasNamePrefix();
  
  /**
   * Method is deprecated. use withNamePrefix instead.
   */
  @java.lang.Deprecated
  public A withNewNamePrefix(java.lang.String arg0);
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerCaptureHTTPCookieFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface IngressControllerCaptureHTTPCookieFluent<A extends io.fabric8.openshift.api.model.operator.v1.IngressControllerCaptureHTTPCookieFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMatchType();
  public A withMatchType(java.lang.String matchType);
  public java.lang.Boolean hasMatchType();
  
  /**
   * Method is deprecated. use withMatchType instead.
   */
  @java.lang.Deprecated
  public A withNewMatchType(java.lang.String arg0);
  public java.lang.Integer getMaxLength();
  public A withMaxLength(java.lang.Integer maxLength);
  public java.lang.Boolean hasMaxLength();
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getNamePrefix();
  public A withNamePrefix(java.lang.String namePrefix);
  public java.lang.Boolean hasNamePrefix();
  
  /**
   * Method is deprecated. use withNamePrefix instead.
   */
  @java.lang.Deprecated
  public A withNewNamePrefix(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
